-- TODO: Need to preserve a way to *not* write the .po files, in case installer needs to do manual .po rewrite...

-- Rewrites .po files in www/languages/*.po on controller...
-- @tPoRewrites -     Array of {["msgid"] = "Name with suffix", ["msgstr"] = "Original name"}
-- @strLanguagePath - Path to languages directory, relative to driver's c4z dir. E.g. for absolute
--                    path /mnt/internal/c4z/knx_thermostat/www/languages/ only
--                    knx_thermostat/www/languages/ should be specified
function RewritePOFiles(tPoRewrites, strLanguagesPath)
  assert(strLanguagesPath ~= nil, "Missing languages director path")
  assert(tPoRewrites ~= nil, "Missing tPoRewrites argument")

  if #tPoRewrites == 0 then return end

  local languagesDir = C4:GetC4zDir() .. strLanguagesPath

  C4:FileSetDir(languagesDir)
  local filelist = C4:FileList()
  for _,v in pairs(filelist) do
    -- Check that it's a .po file...
    if (v:find("%.po")) then
      local fh = C4:FileOpen(v)
      C4:FileSetPos(fh, 0)
      local content = C4:FileRead(fh, 50000)
      C4:FileClose(fh)

      local _, fstart = content:find("%[AUTO_GENERATED_START%]\n")
      local fend = content:find("#%s*%[AUTO_GENERATED_END%]")
      local autoGenContent = content:sub(fstart, fend)

      local currentPoRewrites = POFileGetModes(autoGenContent)
      for _,item in pairs(tPoRewrites) do
        -- Do not write modes that already exist in language files
        -- Do not write modes to .po files that have the same original and display name
        if (not GetMsgid(currentPoRewrites, item.msgid)) and (item.msgid ~= item.msgstr) then
          autoGenContent = autoGenContent .. '\n'
          autoGenContent = autoGenContent .. 'msgid \"' .. item.msgid .. '\"\n'
          autoGenContent = autoGenContent .. 'msgstr \"' .. item.msgstr .. '\"\n'
        end
      end

      local newcontent = content:sub(0, fstart) .. "\n" .. autoGenContent .. "\n" .. content:sub(fend)
      local fh = C4:FileOpen(v)
      C4:FileSetPos(fh, 0)
      C4:FileWriteString(fh, newcontent)
      C4:FileClose(fh)
    end
  end

  C4:FileSetDir("")
end

function POFileGetModes(content)
  local ret = {}
  for original, replace in string.gmatch(content, 'msgid%s+\"(.-)\"%s+msgstr%s+\"(.-)\"%s+') do
    table.insert(ret, { msgid = original, msgstr = msgstr })
  end

  return ret
end

function GetMsgid(poRewrites, msgid)
  for _, item in pairs(poRewrites) do if (item.msgid == msgid) then return item end end
  return nil
end