-- Now allows for 'named' one-shot timers.  If the name is re-used, reset timer, don't make a new one...

---------------------------------------------------------
--------------  OneShotTimer Timers Module  ----------------
---------------------------------------------------------
do
  local OTE, ODD
  local MTFUNC = function() end

  OneShotTimer = {}
  local tCallback = {}
  
  function OneShotTimer.OnTimerExpired(idTimer)
    if (tCallback[idTimer] ~= nil) then
      C4:KillTimer(idTimer)
      tCallback[idTimer].CALLBACK(tostring(tCallback[idTimer].NAME))
      tCallback[idTimer] = nil
    else
      OTE(idTimer)
    end
  end

  function OneShotTimer.ClearAll()
    for k,v in pairs(tCallback) do C4:KillTimer(k) end
    tCallback = {}
  end

  function OneShotTimer.OnDriverDestroyed()
    OneShotTimer.ClearAll()
    ODD()
  end

  function OneShotTimer.Kill(Name)
    if (Name ~= nil) then
      for k,v in pairs(tCallback) do if (v.NAME == Name) then C4:KillTimer(k) tCallback[k] = nil end end
    end
  end

  function OneShotTimer.Add(nInterval, strUnits, fCallback, Name)
    local id = C4:AddTimer(nInterval, strUnits)
    --print("Adding OneShotTimer[" .. nInterval .. " " .. strUnits .. "]: " .. Name)

    -- Look for name if not nil, if found, remove existing timer callback...
    if (Name ~= nil) then
      for k,v in pairs(tCallback) do
        if (v.NAME == Name) then 
	  --print("Killing OneShotTimer Callback: " .. Name)
          C4:KillTimer(k)
          tCallback[k] = nil
        end
      end
    end
    tCallback[id] = {CALLBACK = fCallback, NAME = Name}
  end

  -----  Overrides:  --------
  OTE , OnTimerExpired = OnTimerExpired or MTFUNC, OneShotTimer.OnTimerExpired
  ODD , OnDriverDestroyed = OnDriverDestroyed or MTFUNC, OneShotTimer.OnDriverDestroyed
  ---  END Overrides:  ------
end
---------------------------------------------------------
-----------  END OneShotTimer Timers Module  ---------------
---------------------------------------------------------
